==> isis-fish-4.2.0.1-sources.jar: fr/ifremer/isisfish/ui/CommonHandler.java <==
/*
 * #%L
 * 
 * 
 * $Id: CommonHandler.java 3445 2011-07-15 13:12:45Z chatellier $
 * $HeadURL: http://svn.forge.codelutin.com/svn/isis-fish/tags/isis-fish-4.2.0.1/src/main/java/fr/ifremer/isisfish/ui/CommonHandler.java $
 * %%
 * Copyright (C) 2011 Ifremer, Codelutin, Chatellier Eric
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * #L%
 */

package fr.ifremer.isisfish.ui;

import jaxx.runtime.JAXXContext;
import jaxx.runtime.JAXXUtil;
import fr.ifremer.isisfish.ui.WelcomePanelUI;

/**
 * Common action for all handler.
 * 
 * @author chatellier
 * @version $Revision: 3445 $
 * 
 * Last update : $Date: 2011-07-15 15:12:45 +0200 (Fri, 15 Jul 2011) $
 * By : $Author: chatellier $
 */
public class CommonHandler {

    /**
     * Set main application status bar context.
     * 
     * @param context context
     * @param s string to set
     */
    protected void setStatusMessage(JAXXContext context, String s) {
        WelcomePanelUI root = context.getContextValue(WelcomePanelUI.class, JAXXUtil.PARENT);
        if (root != null) {
            root.setStatusMessage(s);
        }
    }
    
    /**
     * Set main application status bar context.
     * 
     * @param context context
     * @param s string to set
     * @param running enable progress bar running state
     */
    protected void setStatusMessage(JAXXContext context, String s, boolean running) {
        WelcomePanelUI root = context.getContextValue(WelcomePanelUI.class, JAXXUtil.PARENT);
        if (root != null) {
            root.setStatusMessage(s, running);
        }
    }
}

==> isis-fish-4.3.0.0-sources.jar: fr/ifremer/isisfish/ui/CommonHandler.java <==
/*
 * #%L
 * $Id: CommonHandler.java 3798 2012-10-30 10:39:32Z echatellier $
 * $HeadURL: https://svn.codelutin.com/isis-fish/tags/isis-fish-4.3.0.0/src/main/java/fr/ifremer/isisfish/ui/CommonHandler.java $
 * %%
 * Copyright (C) 2011 Ifremer, Codelutin, Chatellier Eric
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

package fr.ifremer.isisfish.ui;

import jaxx.runtime.JAXXContext;
import jaxx.runtime.JAXXUtil;
import fr.ifremer.isisfish.ui.WelcomePanelUI;

/**
 * Common action for all handler.
 * 
 * @author chatellier
 * @version $Revision: 3798 $
 * 
 * Last update : $Date: 2012-10-30 11:39:32 +0100 (Tue, 30 Oct 2012) $
 * By : $Author: echatellier $
 */
public class CommonHandler {

    /**
     * Set main application status bar context.
     * 
     * @param context context
     * @param s string to set
     */
    protected void setStatusMessage(JAXXContext context, String s) {
        WelcomePanelUI root = context.getContextValue(WelcomePanelUI.class, JAXXUtil.PARENT);
        if (root != null) {
            root.setStatusMessage(s);
        }
    }
    
    /**
     * Set main application status bar context.
     * 
     * @param context context
     * @param s string to set
     * @param running enable progress bar running state
     */
    protected void setStatusMessage(JAXXContext context, String s, boolean running) {
        WelcomePanelUI root = context.getContextValue(WelcomePanelUI.class, JAXXUtil.PARENT);
        if (root != null) {
            root.setStatusMessage(s, running);
        }
    }
}
